SEXP
    Matrix_DIsqrtSym,
    Matrix_DSym,
    Matrix_DimSym,
    Matrix_DimNamesSym,
    Matrix_GpSym,
    Matrix_LSym,
    Matrix_LiSym,
    Matrix_LinvSym,
    Matrix_LpSym,
    Matrix_LxSym,
    Matrix_OmegaSym,
    Matrix_ParentSym,
    Matrix_RXXSym,
    Matrix_RZXSym,
    Matrix_XtXSym,
    Matrix_XtySym,
    Matrix_ZZpOSym,
    Matrix_ZZxSym,
    Matrix_ZtXSym,
    Matrix_ZtZSym,
    Matrix_ZtySym,
    Matrix_bVarSym,
    Matrix_cnamesSym,
    Matrix_devCompSym,
    Matrix_devianceSym,
    Matrix_diagSym,
    Matrix_factorSym,
    Matrix_flistSym,
    Matrix_iSym,
    Matrix_ipermSym,
    Matrix_jSym,
    Matrix_matSym,
    Matrix_methodSym,
    Matrix_ncSym,
    Matrix_pSym,
    Matrix_permSym,
    Matrix_rcondSym,
    Matrix_rXySym,
    Matrix_rZySym,
    Matrix_statusSym,
    Matrix_uploSym,
    Matrix_xSym,
    Matrix_zSym;

